package com.nisum.webfluxday2.controller;

import com.nisum.webfluxday2.model.ProductRequest;
import com.nisum.webfluxday2.model.ProductResponse;
import com.nisum.webfluxday2.repository.model.Product;
import com.nisum.webfluxday2.service.ProductService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@RestController
@CrossOrigin(origins = "*")
@RequestMapping("/api")
public class ProductController {

    @Autowired
    ProductService productService;

    @GetMapping("/products")
    public Flux<ProductResponse> getAllProducts(){
        return productService.getAll();
    }

    @GetMapping("/products/{id}")
    public Mono<ProductResponse> findProduct(@PathVariable String id){
        return productService.findProduct(id);
    }

    @PostMapping("/products")
    public Mono<ProductResponse> addNewProduct(@RequestBody ProductRequest productRequest){
        return productService.addProduct(productRequest);
    }

    @PutMapping("/products/{id}")
    public Mono<ProductResponse> alterProduct(@PathVariable String id, @RequestBody ProductRequest productRequest){
        return productService.alterProduct(id, productRequest);
    }

    @DeleteMapping("/products/{id}")
    public Mono<Void> deleteProduct(@PathVariable String id){
        return productService.deleteProduct(id);
    }


}
